package com.xinelu.manage.service.wechattemplate;

import com.xinelu.manage.domain.wechattemplate.WechatTemplate;
import com.xinelu.manage.dto.wechattemplate.WechatTemplateDTO;
import com.xinelu.manage.dto.wechattemplate.WechatTemplateTaskDTO;
import com.xinelu.manage.vo.wechattemplate.WechatTemplateTaskVO;

import java.util.List;

/**
 * 微信模板信息Service接口
 *
 * @author xinelu
 * @date 2024-02-27
 */
public interface IWechatTemplateService {
    /**
     * 查询微信模板信息
     *
     * @param id 微信模板信息主键
     * @return 微信模板信息
     */
    public WechatTemplate selectWechatTemplateById(Long id);

    /**
     * 查询微信模板信息列表
     *
     * @param wechatTemplateDto 微信模板信息
     * @return 微信模板信息集合
     */
    List<WechatTemplateTaskVO> selectWechatTemplateList(WechatTemplateDTO wechatTemplateDto);

    /**
     * 新增微信模板信息
     *
     * @param wechatTemplateTaskDTO 微信模板信息
     * @return 结果
     */
    public int insertWechatTemplate(WechatTemplateTaskDTO wechatTemplateTaskDTO);

    /**
     * 修改微信模板信息
     *
     * @param wechatTemplateTaskDTO 微信模板信息
     * @return 结果
     */
    public int updateWechatTemplate(WechatTemplateTaskDTO wechatTemplateTaskDTO);

    /**
     * 批量删除微信模板信息
     *
     * @param ids 需要删除的微信模板信息主键集合
     * @return 结果
     */
    public int deleteWechatTemplateByIds(Long[] ids);

    /**
     * 删除微信模板信息信息
     *
     * @param id 微信模板信息主键
     * @return 结果
     */
    public int deleteWechatTemplateById(Long id);

    /**
     * 根据id查询微信模板
     */
    WechatTemplateTaskVO selectWechatTemplateDtoById(Long id);
}
